use std::fmt::Display;
use tui::buffer::Buffer;
use tui::layout::Rect;
use tui::style::{Color, Style};
use tui::widgets::{Block, Borders, Paragraph, Widget};

pub enum InputMode {
    Normal,
    Editing,
}

pub struct TextEditorWidget {
    input_mode: InputMode,
    value: String,
    label: String,
}

impl TextEditorWidget {
    pub fn new<D: Display>(label: D, value: D, is_editing: bool) -> Self {
        Self {
            input_mode: match is_editing {
                true => InputMode::Editing,
                false => InputMode::Normal,
            },
            value: value.to_string(),
            label: label.to_string(),
        }
    }
}

impl Widget for TextEditorWidget {
    fn render(self, area: Rect, buf: &mut Buffer) {
        let input = Paragraph::new(self.value.as_ref())
            .style(match &self.input_mode {
                InputMode::Normal => Style::default(),
                InputMode::Editing => Style::default().fg(Color::Yellow),
            })
            .block(
                Block::default()
                    .borders(Borders::ALL)
                    .title(self.label.as_ref()),
            );

        input.render(area, buf);
    }
}
